#!/usr/bin/env python

from distutils.core import setup
from distutils.util import execute
from glob import glob
import os
import commands
import sys

def get_pkgconfig(pack, var):
	cmd = 'pkg-config --variable=%s %s' % (var, pack)
	status, output = commands.getstatusoutput(cmd)
	if not status:
		return output
	else:
		print output
		raise "Error while fiddeling with pkg-config"
try: 
	DESC="Gnome go (igo, baduk, weiqi) game"

	LONG_DESC="""gnomego is a go gui for the gnome desktop. It shall be easy to use as well as beautiful to look at."""

	CLASSIFIERS= [ ]	# TODO

	VERSION = "0.5.1"	#TODO

	try:
		os.chdir(os.path.abspath(os.path.dirname(__file__)))
	except:	
		print "WARNING: setting current working dir failed, build may break!"


	DATA_FILES = []
	SCRIPT_FILES= ['sgf-info']

	# the screensaver module
	hack_dir = get_pkgconfig("gnome-screensaver", "privlibexecdir");
	them_dir = get_pkgconfig("gnome-screensaver", "themesdir");

	DATA_FILES += [(hack_dir, ['sgf-screensaver'])]
	DATA_FILES += [(them_dir, ['data/sgf-screensaver.desktop'])]

	# the nautilus thumbnailer module
	#XXX should be read in via pkg-config but which package defines this ??

	#data/sgf-thumbnailer.schemas is generated from data/sgf-thumbnailer.schemas.in
	#because the install path of sgf-thumbnailer binary has to be adopted
	try:
		os.remove('data/sgf-thumbnailer.schemas')	# Remove old file
	except:
		pass

	cmd = 'sed -e"s,THUMBNAILER_INSTALL_DIR,%s," data/sgf-thumbnailer.schemas.in >  data/sgf-thumbnailer.schemas' % '/usr/bin'
	status, output = commands.getstatusoutput(cmd)
	if status:
		print output
		raise "Error when fiddeling with sed"

	DATA_FILES += [("share/gconf/schemas", ['data/sgf-thumbnailer.schemas'])]
	SCRIPT_FILES += ['sgf-thumbnailer']			# will be installed in ${PATH}

	# desktop starter
	#XXX this paths should also be looked up
	DATA_FILES += [("share/applications", ['data/gnomego.desktop'])]
	DATA_FILES += [("share/pixmaps", ['pixmaps/gnomego_64x64.png'])]

	# mime registration
	#XXX this paths should also be looked up
	DATA_FILES += [("share/mime/packages", ['data/gnomego.xml'])]


	#
	#	All files beyond this point get installed in out own prefixed directory
	#

	# the binary
	SCRIPT_FILES += ['gnomego']
	# pixmaps
	DATA_FILES += [("share/gnomego", glob("pixmaps/*png"))]
	DATA_FILES += [("share/gnomego", glob("pixmaps/*svg"))]

	# UI
	DATA_FILES += [("share/gnomego", ['data/gnomego.glade'])]

	# docbook
	DATA_FILES += [("share/gnome/help/gnomego", glob("docbook/*"))]

	# screensaver sgf library
	DATA_FILES += [("share/gnomego/sgfs", ['data/games.zip'])]

	# other files
	DATA_FILES += [("share/doc/gnomego-" + VERSION, ["AUTHORS", "LICENSE", "README", "TODO"])]

	# Languages
	for lang in os.listdir("lang"):
		if not os.path.isdir("lang/"+ lang): continue
		if lang == '.svn': continue
		print "creating lang/" + lang + "/gnomego.mo"
		s = commands.getstatusoutput('msgfmt lang/' + lang + '/gnomego.po -o lang/' + lang + '/gnomego.mo')
		if not s: print "FAILED"
		DATA_FILES += [("share/locale/" + lang + "/LC_MESSAGES", ["lang/" + lang + "/gnomego.mo"])]

	PACKAGES = ["gnomego"]

	#preprocess preferences.py.in and generate a preferences.py file out of it
	try:
		os.remove('lib/gnomego/preferences.py')	# Remove old file
	except:
		pass

	# figure out where gnugo is installed
	cmd = 'which gnugo'
	status, output = commands.getstatusoutput(cmd)
	if status:
		print output
		raise "Error when fiddeling with which"

	cmd = 'sed -e"s,NAMEOFTHEGAME,%s," lib/gnomego/preferences.py.in > lib/gnomego/preferences.py' % (output + ' --mode gtp')
	status, output = commands.getstatusoutput(cmd)
	if status:
		print output
		raise "Error when fiddeling with sed"

	cmd = 'sed -i -e"s,INSTALLEDPREFIX,%s," lib/gnomego/preferences.py' % '/usr/share/gnomego/'
	status, output = commands.getstatusoutput(cmd)
	if status:
		print output
		raise "Error when fiddeling with sed"

	cmd = 'sed -i -e"s,GNOMEGOVERSION,%s," lib/gnomego/preferences.py' % VERSION
	status, output = commands.getstatusoutput(cmd)
	if status:
		print output
		raise "Error when fiddeling with sed"



	setup(
		name = "gnomego",
		version = VERSION,
		classifiers = CLASSIFIERS,
		description = DESC,
		long_description = LONG_DESC,
		author = "Roland Lezuo",
		author_email = "roland.lezuo@chello.at",
		license = "GPL2",
		url = "foo",
		download_url = "bar",
		packages = PACKAGES,
		package_dir = {'':'lib'},
		data_files = DATA_FILES,
		scripts = SCRIPT_FILES
	)
finally:
	# Remove files generated by the script
	try:
		os.remove('data/sgf-thumbnailer.schemas')
	except: 
		pass
	try:
		os.remove('lib/gnomego/preferences.py')
	except:
		pass
